@@ -6,6 +6,9 @@ use warnings;
 use base 'Mojo::Base';
 
 require Carp;
+use Mojo::Transaction;
+
+__PACKAGE__->attr(tx => sub { Mojo::Transaction->new });
 
 sub get { Carp::croak('Method "get" not implemented by subbclass') }
 
